@@ -1,5 +1,5 @@
 package Getopt::Flex;
-our $VERSION = '0.65';
+our $VERSION = '0.70';
 
 # ABSTRACT: Option parsing, done different.
 
@@ -596,6 +596,13 @@ sub get_desc {
 
 
 
+sub get_switch {
+    my ($self, $switch) = @_;
+    
+    return $self->_spec()->get_switch($switch);
+}
+
+
 no Moose;
 
 1;
@@ -609,7 +616,7 @@ Getopt::Flex - Option parsing, done different.
 
 =head1 VERSION
 
-version 0.65
+version 0.70
 
 =head1 SYNOPSIS
 
@@ -743,8 +750,11 @@ options. For instance,
 
 Defines a switch called I<file> with an alias I<f> which will set variable
 C<$var> with a value when encountered during processing. I<type> specifies
-the type that the input must conform to. Both I<var> and I<type> are required
-when specifying an option. In general, options must conform to the following:
+the type that the input must conform to. Only I<type> is required
+when specifying an option. If no I<var> is supplied, you may still access
+that switch through the C<get_switch> method. It is recommended that you do
+provide a I<var>, however. For more information about C<get_switch> see
+L<get_switch>. In general, options must conform to the following:
 
   $_ =~ m/^[a-zA-Z0-9|_?-]+$/ && $_ =~ m/^[a-zA-Z_?]/ && $_ !~ m/\|\|/ && $_ !~ /--/ && $_ !~ /-$/
 
@@ -775,6 +785,8 @@ and not the variable itself. So C<\$file> is ok, while C<$file> is not.
 You may also pass in an array reference or a hash reference, please see
 L<Specifying a type> for more information.
 
+Specifying a I<var> is optional, as discussed above.
+
 =head2 Specifying a type
 
 A valid type is any type that is "simple" or an ArrayRef or HashRef parameterized
@@ -817,7 +829,7 @@ or
 
 For more information about types and defining your own types, see L<Moose::Manual::Types>.
 
-All of the following arguments to the option specification are optional.
+Specifying a I<type> is required.
 
 =head2 Specifying a desc
 
@@ -826,11 +838,15 @@ to provide an autogenerated help message for that switch. If left empty,
 no information about that switch will be displayed in the help output.
 See L<Getting started with Getopt::Flex> for more information.
 
+Specifying a I<desc> is optional, and defaults to ''.
+
 =head2 Specifying required
 
 Setting I<required> to a true value will cause it make that value required
 during option processing, and if it is not found will cause an error condition.
 
+Specifying I<required> is not required, and defaults to 0.
+
 =head2 Specifying a validator
 
 A I<validator> is a function that takes a single argument and returns a boolean
@@ -838,11 +854,15 @@ value. Getopt::Flex will call the validator function when the option is
 encountered on the command line and pass to it the value it finds. If the value
 does not pass the supplied validation check, an error condition is caused.
 
+Specifying a I<validator> is not required.
+
 =head2 Specifying a callback
 
 A I<callback> is a function that takes a single argument which Getopt::Flex will
 then call when the option is encountered on the command line, passing to it the value it finds.
 
+Specifying a I<callback> is not required.
+
 =head2 Specifying a default
 
 I<default>s come in two flavors, raw values and subroutine references.
@@ -868,6 +888,8 @@ This is due to the way Perl handles such syntax. Additionally, defaults
 must be valid in relation to the specified type and any specified
 validator function. If not, an error condition is signalled.
 
+Specifying a I<default> is not required.
+
 =head1 Configuring Getopt::Flex
 
 Configuration of Getopt::Flex is very simple. Such a configuration
@@ -1032,6 +1054,13 @@ Returns the supplied description, or a single newline if none provided.
 
 Returns an error message if set, empty string otherwise.
 
+=head2 get_switch
+
+Passing this function the name of a switch (or the switch spec) will
+cause it to return the value of a ScalarRef, a HashRef, or an ArrayRef
+(based on the type given), or undef if the given switch does not
+correspond to any defined switch.
+
 =for Pod::Coverage   BUILD
 
 =head1 AUTHOR
