@@ -1,5 +1,5 @@
 package Getopt::Flex::Spec::Argument;
-our $VERSION = '0.65';
+our $VERSION = '0.70';
 
 # ABSTRACT: Getopt::Flex's way of specifying arguments
 
@@ -55,7 +55,8 @@ has 'aliases' => (
 has 'var' => (
     is => 'ro',
     isa => 'ScalarRef|ArrayRef|HashRef',
-    required => 1,
+    writer => '_set_var',
+    predicate => 'has_var',
 );
 
 #the type of values to accept for this variable                
@@ -118,7 +119,6 @@ has 'error' => (
     writer => '_set_error',
 );
             
-            
 
 sub BUILD {
     my ($self) = @_;
@@ -143,6 +143,19 @@ sub BUILD {
         Carp::confess "Given type (or parameter) $type is not simple, i.e. it must be a subtype of Str, Num, Int, or Bool\n";
     }
     
+    if(!$self->has_var()) {
+        if($self->type() =~ /^ArrayRef/) {
+            my @arr = ();
+            $self->_set_var(\@arr);
+        } elsif($self->type() =~ /^HashRef/) {
+            my %has = ();
+            $self->_set_var(\%has);
+        } else {
+            my $var;
+            $self->_set_var(\$var);
+        }
+    }
+    
     #check supplied reference type
     my $reft = ref($self->var());
     if($reft ne 'ARRAY' && $reft ne 'HASH' && $reft ne 'SCALAR') {
@@ -358,7 +371,7 @@ Getopt::Flex::Spec::Argument - Getopt::Flex's way of specifying arguments
 
 =head1 VERSION
 
-version 0.65
+version 0.70
 
 =head1 DESCRIPTION
 
